@@ -42,6 +42,8 @@ static PylibMC_Client *PylibMC_ClientType_new(PyTypeObject *type,
     self = (PylibMC_Client *)type->tp_alloc(type, 0);
     if (self != NULL) {
         self->mc = memcached_create(NULL);
+    } else {
+        args = kwds = NULL;
     }
 
     return self;
@@ -58,6 +60,8 @@ static int PylibMC_Client_init(PylibMC_Client *self, PyObject *args,
 
     if (!PyArg_ParseTuple(args, "O", &srv_list)) {
         return -1;
+    } else {
+        kwds = NULL;
     }
 
     if ((srv_list_it = PyObject_GetIter(srv_list)) != NULL) {
@@ -174,12 +178,13 @@ static PyObject *PylibMC_Client_get(PylibMC_Client *self, PyObject *arg) {
 }
 
 /* {{{ Set commands (set, replace, add, prepend, append) */
-static PyObject *_PylibMC_RunSetCommand(PylibMC_Client *self, _PylibMC_SetCommand f,
-        char *fname, PyObject *args, PyObject *kwds) {
+static PyObject *_PylibMC_RunSetCommand(PylibMC_Client *self,
+        _PylibMC_SetCommand f, char *fname, PyObject *args,
+        PyObject *kwds) {
     char *key;
-    size_t key_len;
+    int key_len;
     PyObject *val, *retval;
-    time_t time;
+    unsigned int time;
     static char *kws[] = { "key", "val", "time", NULL };
 
     retval = NULL;
@@ -274,8 +279,8 @@ static PyObject *PylibMC_Client_append(PylibMC_Client *self, PyObject *args,
 static PyObject *PylibMC_Client_delete(PylibMC_Client *self, PyObject *args) {
     PyObject *retval;
     char *key;
-    size_t key_len;
-    time_t time;
+    int key_len;
+    unsigned int time;
     memcached_return rc;
 
     retval = NULL;
@@ -304,7 +309,7 @@ static PyObject *_PylibMC_IncDec(PylibMC_Client *self, uint8_t dir,
         PyObject *args) {
     PyObject *retval;
     char *key;
-    size_t key_len;
+    int key_len;
     unsigned int delta;
     uint64_t result;
 
@@ -336,7 +341,9 @@ static PyObject *PylibMC_Client_get_multi(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
     PyObject *key_seq, **key_objs, *retval = NULL;
     char **keys, *prefix = NULL;
-    size_t *key_lens, nkeys, prefix_len = 0;
+    unsigned int prefix_len = 0;
+    size_t *key_lens;
+    Py_ssize_t nkeys;
     memcached_return rc;
 
     char curr_key[MEMCACHED_MAX_KEY];
@@ -348,7 +355,7 @@ static PyObject *PylibMC_Client_get_multi(PylibMC_Client *self, PyObject *args,
     if (PyArg_ParseTupleAndKeywords(args, kwds, "O|s#", kws,
                 &key_seq, &prefix, &prefix_len)) {
         PyObject *key_it, *ckey;
-        int i;
+        Py_ssize_t i;
 
         /* First clear any potential earlier mishap because we rely on it in
          * our iteration over keys. */
@@ -744,7 +751,7 @@ static int _PylibMC_CheckKey(PyObject *key) {
             PyString_AS_STRING(key), PyString_GET_SIZE(key));
 }
 
-static int _PylibMC_CheckKeyStringAndSize(char *key, size_t size) {
+static int _PylibMC_CheckKeyStringAndSize(char *key, int size) {
     if (size > MEMCACHED_MAX_KEY) {
         PyErr_Format(PyExc_ValueError, "key too long, max is %d",
                 MEMCACHED_MAX_KEY);
@@ -752,11 +759,11 @@ static int _PylibMC_CheckKeyStringAndSize(char *key, size_t size) {
     }
     /* TODO Check key contents here. */
 
-    return 1;
+    return key != NULL;
 }
 
 static PyMethodDef PylibMC_functions[] = {
-    {NULL}
+    {NULL, NULL, 0, NULL}
 };
 
 PyMODINIT_FUNC init_pylibmc(void) {
