@@ -66,16 +66,26 @@ typedef struct {
 
 static PylibMC_Behavior PylibMC_behaviors[] = {
     { MEMCACHED_BEHAVIOR_NO_BLOCK, "no block" },
-    { MEMCACHED_BEHAVIOR_TCP_NODELAY, "tcp nodelay" },
+    { MEMCACHED_BEHAVIOR_TCP_NODELAY, "tcp_nodelay" },
     { MEMCACHED_BEHAVIOR_HASH, "hash" },
+    { MEMCACHED_BEHAVIOR_KETAMA, "ketama" },
     { MEMCACHED_BEHAVIOR_DISTRIBUTION, "distribution" },
-    { MEMCACHED_BEHAVIOR_CACHE_LOOKUPS, "cache lookups" },
-    { MEMCACHED_BEHAVIOR_SUPPORT_CAS, "support cas" },
-    { MEMCACHED_BEHAVIOR_POLL_TIMEOUT, "poll timeout" },
-    { MEMCACHED_BEHAVIOR_BUFFER_REQUESTS, "buffer requests" },
-    { MEMCACHED_BEHAVIOR_VERIFY_KEY, "verify key" },
-    { MEMCACHED_BEHAVIOR_SORT_HOSTS, "sort hosts" },
-    { MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT, "connect timeout" },
+    { MEMCACHED_BEHAVIOR_SOCKET_SEND_SIZE, "socket send size" },
+    { MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE, "socket recv size" },
+    { MEMCACHED_BEHAVIOR_CACHE_LOOKUPS, "cache_lookups" },
+    { MEMCACHED_BEHAVIOR_SUPPORT_CAS, "support_cas" },
+    { MEMCACHED_BEHAVIOR_POLL_TIMEOUT, "poll_timeout" },
+    { MEMCACHED_BEHAVIOR_BUFFER_REQUESTS, "buffer_requests" },
+    { MEMCACHED_BEHAVIOR_SORT_HOSTS, "sort_hosts" },
+    { MEMCACHED_BEHAVIOR_VERIFY_KEY, "verify_key" },
+    { MEMCACHED_BEHAVIOR_CONNECT_TIMEOUT, "connect_timeout" },
+    { MEMCACHED_BEHAVIOR_RETRY_TIMEOUT, "retry_timeout" },
+    { MEMCACHED_BEHAVIOR_KETAMA_WEIGHTED, "ketama_weighted" },
+    { MEMCACHED_BEHAVIOR_KETAMA_HASH, "ketama_hash" },
+    { MEMCACHED_BEHAVIOR_BINARY_PROTOCOL, "binary_protocol" },
+    { MEMCACHED_BEHAVIOR_SND_TIMEOUT, "snd_timeout" },
+    { MEMCACHED_BEHAVIOR_RCV_TIMEOUT, "rcv_timeout" },
+    { MEMCACHED_BEHAVIOR_SERVER_FAILURE_LIMIT, "server_failure_limit" },
     { 0, NULL }
 };
 
@@ -87,6 +97,8 @@ static PylibMC_Behavior PylibMC_hashers[] = {
     { MEMCACHED_HASH_FNV1A_64, "fnv1a_64" },
     { MEMCACHED_HASH_FNV1_32, "fnv1_32" },
     { MEMCACHED_HASH_FNV1A_32, "fnv1a_32" },
+    { MEMCACHED_HASH_HSIEH, "hsieh" },
+    { MEMCACHED_HASH_MURMUR, "murmur" },
     { 0, NULL }
 };
 
